@@ -3,9 +3,9 @@ Runs libEnsemble with a non-persistent generator performing uniform random
 sampling.
 
 Execute via one of the following commands (e.g. 3 workers):
-   mpiexec -np 4 python3 test_uniform_sampling.py
-   python3 test_uniform_sampling.py --nworkers 3 --comms local
-   python3 test_uniform_sampling.py --nworkers 3 --comms tcp
+   mpiexec -np 4 python test_uniform_sampling.py
+   python test_uniform_sampling.py --nworkers 3 --comms local
+   python test_uniform_sampling.py --nworkers 3 --comms tcp
 
 The number of concurrent evaluations of the objective function will be 4-1=3.
 """
@@ -47,7 +47,7 @@ gen_specs = {
 
 persis_info = add_unique_random_streams({}, nworkers + 1)
 
-exit_criteria = {'gen_max': 501, 'elapsed_wallclock_time': 300}
+exit_criteria = {'gen_max': 501, 'wallclock_max': 300}
 
 # Perform the run
 H, persis_info, flag = libE(sim_specs, gen_specs, exit_criteria, persis_info, libE_specs=libE_specs)
